<?php 

$lang['user_title'] = 'Пользователи';
$lang['role_title'] = 'Роли';
$lang['rule_title'] = 'Правила';

$lang['fail'] = 'Ошибка сохранения данных';
$lang['success'] = 'Данные сохранены';

$lang['acl_action_name'] = 'Действия';
$lang['acl_role_name'] = 'Роль';
$lang['login'] = 'Логин';
$lang['password'] = 'Пароль';
$lang['photo'] = 'Фото';
$lang['email'] = 'Email';
$lang['birth_date'] = 'Дата рождиния';
$lang['registered'] = 'Зарегистрирован';
$lang['confirmed'] = 'Подтвержден';
$lang['acl_active'] = 'Активно';
$lang['acl_role_parent_id'] = 'Унаследовано';
$lang['acl_resource_name'] = 'Ресурс';
$lang['acl_resource_alias'] = 'Псевдоним ресурса';
$lang['pass_changed'] = 'Пароль изменено';
$lang['pass_fail'] = 'Ошибка изменения пароля';
$lang['change_pass_dialog'] = 'Изменить пароль';
$lang['change_info'] = 'Изменить информацию пользователя';
$lang['password'] = 'Пароль';
$lang['password1'] = 'Пароль еще раз';
$lang['add_new_user'] = 'пользователь';
$lang['add_new_acl_resource'] = 'ресурс';
$lang['add_new_acl_role'] = 'роль';

$lang['back_to_list'] = 'Вернутся к списку';