<?php

if (!defined('BASEPATH'))
    exit('No direct script access allowed');

/**
 * Zend_init Class
 *
 * @package	CodeIgniter
 * @subpackage	Libraries
 * @category	Libraries
 * @author	R-Team
 * @link	http://r-team.com.ua
 */
class zend_init {

    function __construct() {
        // Init Zend Loader
        ini_set('include_path', ini_get('include_path') . PATH_SEPARATOR . APPPATH . 'third_party/');
        require_once('Zend/Loader.php');
    }

    /**
     * Load Zend ACL
     * @return object
     */
    function Zend_ACL() {
        Zend_Loader::loadClass('Zend_Acl');
        Zend_Loader::loadClass('Zend_Acl_Role');
        Zend_Loader::loadClass('Zend_Acl_Resource');
        return new Zend_Acl();
    }
}

/* End of file zend_init.php */
/* Location: ./application/libraries/Zend_init.php */