<?php 

$lang['user_title'] = 'Users';
$lang['role_title'] = 'Roles';
$lang['rule_title'] = 'Rules';

$lang['fail'] = 'Saving data error';
$lang['success'] = 'Saving complete';

$lang['acl_action_name'] = 'Actions';
$lang['acl_role_name'] = 'Role';
$lang['login'] = 'Login';
$lang['password'] = 'Password';
$lang['photo'] = 'Photo';
$lang['email'] = 'Email';
$lang['birth_date'] = 'Birth date';
$lang['registered'] = 'Registered';
$lang['confirmed'] = 'Confirmed';
$lang['acl_active'] = 'Active';
$lang['acl_role_parent_id'] = 'Parent role';
$lang['acl_resource_name'] = 'Resource';
$lang['acl_resource_alias'] = 'Resource alias';
$lang['pass_changed'] = 'Password changed';
$lang['pass_fail'] = 'Password changing error';
$lang['change_pass_dialog'] = 'Change password';
$lang['change_info'] = 'Change user info';
$lang['password'] = 'Password';
$lang['password1'] = 'Repeat password';
$lang['add_new_user'] = 'user';
$lang['add_new_acl_resource'] = 'resource';
$lang['add_new_acl_role'] = 'role';

$lang['back_to_list'] = 'Back to list';