<!DOCTYPE html>
<html>
    <head>
        <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <title>{title}</title>
        {js_list}
        {css_list}
    </head>
    <body>
        <div class="fake-header"></div>
        <div class="container">
            <header>
                <a href="/" target="_blank"><div class="logo"></div></a>
                <ul class="topnav">
                    {top_menu}
                        <li class="{active} {non-active}"><a href="{href}" {id}>{name}</a></li>
                    {/top_menu}
                </ul>
                {user_info}
            </header>            
            <div class="wrapper">
                {admin_menu}
                <h1>{title}</h1>
                <hr/>
                {user_left_menu}
                <div class="content">{content}</div>
            </div>

            <footer>
                <p class="created">UI design by <a href="http://www.dsnv.com.ua">DSNV game changers</a> & Programming by <a href="http://www.r-team.com.ua">R-team</a></p>
            </footer>
        </div>

    </body>
</html>