<?php

$lang['title'] = 'Встановлення';
$lang['ln_menu_title'] = 'Кроки встановлення';

$lang['step_nav_items'] = array(
    'check_folders' => 'Перевірка доступності каталогів',
    'configuration' => 'Конфігурація системи',
    'database' => 'Конфігурація бази даних',
    'modules' => 'Встановлення модулів'
);
$lang['check_folders_info'] = 'Каталоги, зазначені нижче, повинні мати доступ на запис (775)';

$lang['ln_folder_name'] = 'Каталог';
$lang['ln_folder_status'] = 'Статус';
$lang['ln_btn_next'] = 'Далі';

$lang['admin_page'] = 'Адіин. сторінка';
$lang['ln_encryption_key'] = 'Секретний ключ';
$lang['ln_language'] = 'Мова системи';
$lang['user_data'] = 'супер користувач';
$lang['login'] = 'Логін';
$lang['pass'] = 'Пароль';
$lang['cpass'] = 'Пароль ще раз';

$lang['db_data'] = 'База даних';
$lang['hostname'] = 'Хост';
$lang['database'] = 'База даних';

// ACL
$lang['acl_title'] = 'ACL';
$lang['acl_actions'] = array(
    'view_user' => 'Список користувачів',
    'insert_user' => 'Додати користувача',
    'edit_user' => 'Редагувати користувача',
    'delete_user' => 'Видалити користувача',
    'change_user_pass' => 'Змінити пароль користувача',
    'view_role' => 'Список ролей',
    'insert_role' => 'Додати роль',
    'edit_role' => 'Редагувати роль',
    'delete_role' => 'Видалити роль',
    'edit_rule' => 'Правила доступа'
);
$lang['system_title'] = 'Система';
$lang['system_actions'] = array(
    'view_amenu' => 'Перегляд адмін меню',
    'view_admin' => 'Адмін. панель',
    'edit_amenu' => 'Керування адмін меню',
    'module_manager' => 'Встановлення/Видалення модулів',
    'language_manager' => 'Налаштування мов системи',
    'backup_db' => 'Резервна копія бази даних'
);

$lang['finish_info'] = 'Система успішно встановлена.';
$lang['admin_link_txt'] = 'Увійти в адмін. панель';