<?php

$lang['title'] = 'Установка';
$lang['ln_menu_title'] = 'Шаги установки';

$lang['step_nav_items'] = array(
    'check_folders' => 'Проверка доступа каталогов',
    'configuration' => 'Конфигурация системы',
    'database' => 'Конфигурация базы данных',
    'modules' => 'Установка модулей'
);
$lang['check_folders_info'] = 'Каталоги отмеченные ниже должны быть доступны для записи (775)';

$lang['ln_folder_name'] = 'Каталог';
$lang['ln_folder_status'] = 'Статус';
$lang['ln_btn_next'] = 'Далее';

$lang['admin_page'] = 'Админ. страница';
$lang['ln_encryption_key'] = 'Секретный ключ';
$lang['ln_language'] = 'Язык системы';
$lang['user_data'] = 'супер пользователя';
$lang['login'] = 'Логин';
$lang['pass'] = 'Пароль';
$lang['cpass'] = 'Подтверждение пароля';

$lang['db_data'] = 'База данных';
$lang['hostname'] = 'Хост';
$lang['database'] = 'База данных';

// ACL
$lang['acl_title'] = 'ACL';
$lang['acl_actions'] = array(
    'view_user' => 'Список пользователей',
    'insert_user' => 'Добавить пользователя',
    'edit_user' => 'Редактировать пользователя',
    'delete_user' => 'Удалить пользователя',
    'change_user_pass' => 'Изменить пароль пользователя',
    'view_role' => 'Список ролей',
    'insert_role' => 'Добавить роль',
    'edit_role' => 'Редактировать роль',
    'delete_role' => 'Удалить роль',
    'edit_rule' => 'Правила доступа'
);
$lang['system_title'] = 'Система';
$lang['system_actions'] = array(
    'view_amenu' => 'Просмотр админ меню',
    'view_admin' => 'Админка',
    'edit_amenu' => 'Управление админ меню',
    'module_manager' => 'Установка/Удаление модулей',
    'language_manager' => 'Настройка языков системы',
    'backup_db' => 'Резервная копия базы данных'
);

$lang['finish_info'] = 'Система успешно установлена.';
$lang['admin_link_txt'] = 'Войти в админ. панель';