<?php 

$config['export_config_file_path'] = APPPATH . 'system/ciext/config/export';

$config['check_folders'] = array(
    APPPATH . 'cache',
    APPPATH . 'config',
    APPPATH . 'logs',
    APPPATH . 'modules',
    'assets/uploads'
);

$config['auto_installing_modules'] = array(
    'resmng',
    'cache',
    'skeleton',
    'filemanager',
    'user_menu',
    'seo'
);
